@@ -28,24 +28,35 @@ test_that("data.frame assignment", {
   exp2 <- remove_labels(x)
 
   expect_equal(get_labels(x), exp)
-  expect_error(assign_labels(x0, a = "x", b = "y", `1` = 2),
-               "Columns not found: a, b, 1")
 
-  expect_error(assign_labels(x0, NULL))
+  expect_error(
+    assign_labels(x0, a = "x", b = "y", `1` = 2),
+    "Columns not found: a, b, 1",
+    class = "assignLabelsDataframeMissingError"
+  )
+
+  expect_error(
+    assign_labels(x0, NULL),
+    class = "assignLabelsDataframeNamesError"
+  )
 
   expect_true(is.null(attr(exp0[["Species"]], "label")))
   expect_equal(attr(exp0[["Sepal.Length"]], "label"), "a")
   expect_equal(x0, exp2)
   expect_equal(exp1, exp2)
 
-  expect_error(assign_labels(x0, .ls = list()))
-  expect_error(assign_labels(x0, a = 1, .ls = list(b = 2)))
-
+  expect_error(assign_labels(x0, .ls = list()), class = "simpleError")
+  expect_error(
+    assign_labels(x0, a = 1, .ls = list(b = 2)),
+    class = "assignLabelsDataframeDotsError"
+  )
 
   df <- data.frame(a = 1, b = 2, c = 3)
-  expect_error(assign_labels(df, c = "c", d = "d", .missing = "error"))
-  expect_warning(assign_labels(df, c = "c", d = "d", .missing = "warn"))
+  # nolint start: line_length_linter.
+  expect_error(assign_labels(df, c = "c", d = "d", .missing = "error"), class = "assignLabelsDataframeMissingError")
+  expect_warning(assign_labels(df, c = "c", d = "d", .missing = "warn"), class = "assignLabelsDataframeMissingWarning")
   expect_warning(assign_labels(df, c = "c", d = "d", .missing = "skip"), NA)
+  # nolint end: line_length_linter.
 })
 
 test_that("data.frame assign with data.frame", {
@@ -71,8 +82,12 @@ test_that("data.frame assign with data.frame", {
     v1 = c("a", "b", 1),
     v2 = c("x", "y", 2)
   )
-  expect_error(assign_labels(iris, bad_labels),
-               "Columns not found: a, b, 1")
+
+  expect_error(
+    assign_labels(iris, bad_labels),
+    "Columns not found: a, b, 1",
+    class = "assignLabelsDataframeMissingError"
+  )
 
   options(op)
 })
@@ -82,11 +97,11 @@ test_that("view_labels() works", {
   df <- assign_labels(df, a = "a", b = "b")
 
   # redefine "View"
-  View <- function(x, ...) identity(x)
+  View <- function(x, ...) identity(x) # nolint: object_name_linter.
   expect_error(view_labels(df), NA)
 
-  View <- NA
-  expect_error(view_labels(df), "Something went wrong")
+  View <- NA # nolint: object_name_linter.
+  expect_error(view_labels(df), class = "viewLabelsSomethingError")
 })
 
 test_that("exact match [141]", {
